@@ -17,6 +17,7 @@ from .ScatterMatrix import ScatterMatrix
 from .Table import Table
 from .Violin import Violin
 from .Base import Base
+from .CategoryLookup import CategoryLookup
 from .CombinecatTransform import CombinecatTransform
 from .EvalTransform import EvalTransform
 from .MeltTransform import MeltTransform
@@ -42,6 +43,7 @@ __all__ = [
     "Table",
     "Violin",
     "Base",
+    "CategoryLookup",
     "CombinecatTransform",
     "EvalTransform",
     "MeltTransform",
